package jp.go.ipa.sample.component.activity.exported;

import java.io.File;
import java.util.ArrayList;

import jp.go.ipa.sample.component.activity.exported.R;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.CheckBox;
import android.widget.ListView;
import android.widget.Spinner;
import android.widget.Toast;
import android.app.Activity;
import android.content.Intent;

/**
 * 投稿画像の選択画面Activityクラス
 */
public class ImageSelectActivity extends Activity {

	private final String SAMPLE_NAME = "テストデータ";
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_imageselect);

		setSpinnerValue();

	}

	/**
	 * 「フォルダ選択」のスピナーに表示するフォルダ名を設定
	 */
	private void setSpinnerValue() {

		ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_item);

		String path = Environment.getExternalStorageDirectory().getAbsolutePath() + "/";

		// 全ディレクトリ名を取得
		ArrayList<String> files = getDirName(path, true);

		// 先頭にテスト用データを入れる
		files.add(0,SAMPLE_NAME);

		Spinner spinner = (Spinner) findViewById(R.id.spinner);

		// 読み込んだファイル名をadapterに設定
		for (int i = 0; i < files.size(); i++) {
			adapter.add(files.get(i).toString());
		}

		// アダプターを設定します
		spinner.setAdapter(adapter);

		// スピナーのアイテムが選択された時に呼び出されるコールバックリスナーを登録します
		spinner.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
			@Override
			public void onItemSelected(AdapterView<?> parent, View view,
					int position, long id) {
				Spinner spinner = (Spinner) parent;
				// 選択されたアイテムを取得します
				String item = (String) spinner.getSelectedItem();
				createFileList(item);

			}

			@Override
			public void onNothingSelected(AdapterView<?> arg0) {

			}
		});
	}

	/**
	 * ListViewに表示する値を設定
	 */
	private void createFileList(String dir_path) {

		ListView fileList = (ListView) findViewById(R.id.fileList);
		ArrayAdapter<FileInfo> adapter = new ArrayAdapter<FileInfo>(this,
				android.R.layout.simple_list_item_single_choice);

		if(SAMPLE_NAME.equals(dir_path)){
			adapter.add(new FileInfo("TestPicture1.jpg", SAMPLE_NAME));
			adapter.add(new FileInfo("TestPicture2.jpg", SAMPLE_NAME));
			adapter.add(new FileInfo("TestPictureFailure.jpg", SAMPLE_NAME));
		}else{
			ArrayList<FileInfo> fileArray = readFile(dir_path);

			// 取得したファイル名のリストをListViewに設定する
			for (int i = 0; i < fileArray.size(); i++) {
				adapter.add(fileArray.get(i));
			}
		}
		
		fileList.setAdapter(adapter);
		fileList.setChoiceMode(ListView.CHOICE_MODE_SINGLE);
	}

	/**
	 * 指定したpath直下のファイルをArrayListに設定
	 */
	private ArrayList<FileInfo> readFile(String dir_path) {

		File dir = new File(dir_path);

		int fileCounts = dir.listFiles().length;

		ArrayList<FileInfo> arrayList = new ArrayList<FileInfo>();

		File files[] = dir.listFiles();

		for (int i = 0; i < fileCounts; ++i) {

			// 対象がファイルでない時は何も処理を行わない
			if (!files[i].isFile()) {

			// 対象がファイルの時はリストにファイル名を設定
			} else {
				if (files[i].getName().toLowerCase().endsWith(".png") || 
						files[i].getName().toLowerCase().endsWith(".jpg") ||
						files[i].getName().toLowerCase().endsWith(".jpeg") ||
						files[i].getName().toLowerCase().endsWith(".gif") ||
						files[i].getName().toLowerCase().endsWith(".bmp")) {
					FileInfo fileInfo = new FileInfo(files[i].getName(), files[i].getAbsolutePath());
					arrayList.add(fileInfo);
				}
			}

		}

		return arrayList;
	}

	/**
	 * 投稿ボタンタップ時の処理
	 */
	public void onClickSendPicture(View v) {

		ListView listView =  (ListView) findViewById(R.id.fileList);

		int position = listView.getCheckedItemPosition();
		
		if (position < 0) {

			Toast.makeText(getApplicationContext(), "対象が選択されていません",Toast.LENGTH_LONG).show();

			return;
		}
		
		FileInfo item = (FileInfo) listView.getItemAtPosition(position);

		// リストビューに表示するファイル名の取得
		int pos = listView.getCheckedItemPosition();
		// 投稿するファイルが選択されていない場合は以降の処理は行わない
		if (pos < 0) {
			Toast.makeText(this, "投稿するファイルを選択してください", Toast.LENGTH_SHORT).show();
			return;
		}

		// 画像ファイルかどうかの識別
		if (!item.fileName.toLowerCase().endsWith(".png") && 
			!item.fileName.toLowerCase().endsWith(".jpg") &&
			!item.fileName.toLowerCase().endsWith(".jpeg") &&
			!item.fileName.toLowerCase().endsWith(".gif") &&
			!item.fileName.toLowerCase().endsWith(".bmp")) {
			Toast.makeText(this, "画像ファイルを選択してください", Toast.LENGTH_SHORT).show();
			return;

		}

		// 画像確認のチェック状態
		boolean confirm = ((CheckBox)findViewById(R.id.checkSend)).isChecked();
		
		// intentにファイル名とファイルの絶対パスを設定して送信
		Intent intent = new Intent(ImageSelectActivity.this,UploadActivity.class);

		intent.putExtra("fileName", item.fileName);
		intent.putExtra("dirPath", item.filePath);
		intent.putExtra("confirm", confirm);
		startActivity(intent);
	}

	/**
	 * 全ディレクトリ名を取得する処理
	 */
	public ArrayList<String> getDirName(String dir_path, boolean search_subdir){
		final File dir = new File(dir_path);

		ArrayList<String> find_files = new ArrayList<String>();

		final File[] files = dir.listFiles();

		// ディレクトリの中があるとき
		if (null != files) {

			for (int i = 0; i < files.length; ++i) {
				// files内の対象がディレクトリの時
				if (!files[i].isFile()) {
					if (search_subdir) {
						ArrayList<String> sub_files = getDirName(
								files[i].getPath(), search_subdir);
						find_files.addAll(sub_files);
					}
					// files内の対象がファイルの時
				} else {
					if (files[i].getName().toLowerCase().endsWith(".png") || 
							files[i].getName().toLowerCase().endsWith(".jpg") ||
							files[i].getName().toLowerCase().endsWith(".jpeg") ||
							files[i].getName().toLowerCase().endsWith(".gif") ||
							files[i].getName().toLowerCase().endsWith(".bmp")) {
						escapeSameDirName(find_files, dir.getPath());
					}
				}
			}
		}
		return find_files;
	}

	/**
	 * ディレクトリ内にファイルが2つ以上存在するとき、ファイル数分同じディレクトリ名 をリストビューに設定するのを回避するための処理
	 */
	private void escapeSameDirName(ArrayList<String> find_files, String path) {

		for (int i = 0; i < find_files.size(); i++) {

			if (find_files.get(i) == path) {
				return;
			}

		}

		find_files.add(path);

	}

	/*
	 * 画像ファイルの情報を保持するクラス
	 */
	private class FileInfo {

		public String fileName;

		public String filePath;
		
		/*
		 * コンストラクタ
		 */
		public FileInfo(String fileName, String filePath){
			this.fileName = fileName;
			this.filePath = filePath;
		}

		/*
		 * リスト表示内容取得
		 */
		public String toString(){
			return fileName;
		}

	}
}
