package jp.go.ipa.sample.component.activity.exported;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

import android.app.Activity;
import android.app.ProgressDialog;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

/**
 * 受信した画像ファイルを表示するActivity
 */
public class UploadActivity extends Activity {

	String fileName = null;

	private final String SAMPLE_NAME = "テストデータ";

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_upload);

		// intentの受け取り
		fileName = getIntent().getStringExtra("fileName");
		String filePath = getIntent().getStringExtra("dirPath");
		boolean confirm = getIntent().getBooleanExtra("confirm",true);

		// 画像の表示
		showImage(filePath, confirm);

		// ファイル情報設定
		setFileInfo(fileName);
	}

	/*
	 * 画像の表示
	 */
	private void showImage(String filePath, boolean confirm) {
		// 画像をファイルとして取り出す
		try {
			// 画像ファイルを表示する
			if(SAMPLE_NAME.equals(filePath)){
				// テスト用データの場合はAssetsから読み込む
				InputStream inputStream = getResources().getAssets().open(fileName);
				Bitmap bitmap = BitmapFactory.decodeStream(inputStream);
				ImageView imageUpload = (ImageView) findViewById(R.id.imageUpload);
				imageUpload.setImageBitmap(bitmap);

			}else{
				File file = new File(filePath);
				FileInputStream fileInputStream;
				fileInputStream = new FileInputStream(file);
				Bitmap bitmap = BitmapFactory.decodeStream(fileInputStream);
				ImageView imageUpload = (ImageView) findViewById(R.id.imageUpload);
				imageUpload.setImageBitmap(bitmap);
			}

			if(confirm == false){
				// 確認を行わない場合、即送信処理を行う
				sendPicture();
			}
			
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			// エラー時は画面を終了する
			Toast.makeText(this, "ファイルの取得に失敗しました", Toast.LENGTH_SHORT).show();
			finish();

		} catch (Exception e) {
			e.printStackTrace();
			// エラー時は画面を終了する
			Toast.makeText(this, "ファイルの取得に失敗しました", Toast.LENGTH_SHORT).show();
			finish();

		}
	}

	/*
	 * ファイル情報設定
	 */
	private void setFileInfo(String filePath) {
		TextView textFileInfo = (TextView) findViewById(R.id.textFileInfo);
		textFileInfo.setText(filePath);
	}

	/*
	 * 「はい」ボタンタップ
	 */
	public void onClickYes(View v) {
		// 送信処理を行う
		sendPicture();
	}

	/*
	 * 「いいえ」ボタンタップ
	 */
	public void onClickNo(View v) {
		// 処理を終了する
		finish();
	}

	/*
	 * 送信処理
	 */
	private void sendPicture() {
		// 送信中ダイアログを表示
		final ProgressDialog progressDialog = new ProgressDialog(this);
		progressDialog.setMessage(fileName + "送信中");
		progressDialog.setIndeterminate(false);
		progressDialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
		progressDialog.setCancelable(false);
		progressDialog.show();

		final Handler handler = new Handler();
		// マルチスレッドにて送信処理を行う
		new Thread(new Runnable() {
			@Override
			public void run() {
				// 送信処理を行う（ここでは処理は行わず、2秒間待機）
				try {
					Thread.sleep(2000);
				} catch (InterruptedException e) {
					e.printStackTrace();
				}

				// 送信完了処理を行う
				handler.post(new Runnable() {
					@Override
					public void run() {
						// 送信中ダイアログを閉じる
						progressDialog.dismiss();
						// 送信完了処理を行う
						sendConplete();
					}
				});
			}
		}).start();
	}
	/*
	 * 送信完了処理
	 */
	private void sendConplete() {
		// 完了メッセージの表示
		TextView textMessage = (TextView) findViewById(R.id.textMessage);
		textMessage.setText("投稿が完了しました");

		// 「はい」ボタンを非表示にし、「いいえ」ボタンを完了と表示する。
		Button btnYes = (Button) findViewById(R.id.btnYes);
		btnYes.setVisibility(View.GONE);

		Button btnNo = (Button) findViewById(R.id.btnNo);
		btnNo.setText("完了");
	}
}
