package jp.go.ipa.sample.component.service;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.*;
import android.widget.Toast;

/**
 * バックアップServiceクラス
 */
public class BackupService extends Service {

    protected final IBinder binder = new Binder() {
        @Override
        protected boolean onTransact(int code, Parcel data, Parcel reply, int flags) throws RemoteException {
            return super.onTransact(code, data, reply, flags);
        }
    };

    static String server;

    @Override
    public void onCreate() {

    }

    @Override
    public void onStart(Intent intent, int startId) {
        super.onStart(intent, startId);
        // サービス起動時の処理。
        // サービス起動中に呼ぶと複数回コールされ得る。しかし二重起動はしない

        // タスクを実行
        execTask(intent);
    }

    @Override
    public void onDestroy() {

    }

    @Override
    public IBinder onBind(Intent arg0) {
        return binder;
    }

    /**
     * サービスの定期実行の間隔をミリ秒で指定。
     * 処理が終了してから次に呼ばれるまでの時間。
     */
    protected long getIntervalMS() {
        return 60 * 1000;
    }

    /**
     * 定期実行したいタスクの中身（１回分）
     * タスクの実行が完了したら，次回の実行計画を立てること。
     */
    protected void execTask(Intent intent) {

        // intentからバックアップ先サーバを取得
        if (intent.getStringExtra("server") != null && !"".equals(intent.getStringExtra("server"))) {
            server = intent.getStringExtra("server");
        }

        final Handler handler = new Handler();

        // サーバが取得できたときのみ処理を行う
        if (server != null && !"".equals(server)) {

            // 開始メッセージ表示
            Toast.makeText(BackupService.this, "[バックアップツール]\r\n下記サーバにバックアップ処理を開始します。\r\n" + server, Toast.LENGTH_SHORT).show();

            // 別スレッドにて処理を行う
            new Thread(new Runnable() {
                @Override
                public void run() {
                    // バックアップ処理を行う（サンプルアプリのため処理は行わず、数秒間Sleepする）
                    try {
                        Thread.sleep(5000);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }

                    // 終了メッセージ表示
                    handler.post(new Runnable() {
                        @Override
                        public void run() {
                            Toast.makeText(getApplication().getApplicationContext(), "[バックアップツール]\r\nバックアップ処理が完了しました。", Toast.LENGTH_SHORT).show();
                        }
                    });
                }
            }).start();
        }
        // 次回の実行について計画を立てる
        makeNextPlan();
    }

    /**
     * 次回の実行計画を立てる。
     */
    protected void makeNextPlan() {
        scheduleNextTime();
    }

    /**
     * サービスの次回の起動を予約
     */
    public void scheduleNextTime() {

        long now = System.currentTimeMillis();

        // アラームをセット
        PendingIntent alarmSender = PendingIntent.getService(
                this,
                0,
                new Intent(this, this.getClass()),
                0
        );
        AlarmManager am = (AlarmManager) this.getSystemService(Context.ALARM_SERVICE);
        am.set(
                AlarmManager.RTC,
                now + getIntervalMS(),
                alarmSender
        );
        // 次回登録が完了

    }

    /**
     * サービスの定期実行を解除し，サービスを停止
     */
    public void stopResident(Context context) {
        // サービス名を指定
        Intent intent = new Intent(context, this.getClass());

        // アラームを解除
        PendingIntent pendingIntent = PendingIntent.getService(
                context,
                0, // ここを-1にすると解除に成功しない
                intent,
                PendingIntent.FLAG_UPDATE_CURRENT
        );

        AlarmManager alarmManager = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
        alarmManager.cancel(pendingIntent);

        // サービス自体を停止
        stopSelf();
    }

}
