package jp.go.ipa.sample.component.service.client;

import android.app.ActivityManager;
import android.util.Log;
import android.widget.Button;
import jp.go.ipa.sample.component.service.client.R;
import android.app.Activity;
import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.os.SystemClock;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import java.util.List;

/**
 * バックアップを行うサービス起動をリクエストするアプリ
 * <p/>
 * メイン画面Activityクラス
 */
public class MainActivity extends Activity {


    /**
     * ペンディングインテント
     */
    static private PendingIntent pendingIntent = null;
    /**
     * アラームマネージャー
     */
    static private AlarmManager alarmManager = null;
    /**
     * バックアップサーバリスト
     */
    final private String[] BACKUP_SERVER = {
            "http://www.backupserver1.example.co.jp/",
            "http://www.backupserver2.example.co.jp/",
            "http://www.backupserver3.example.co.jp/",
            "http://www.backupserver4.example.co.jp/",
            "http://www.backupserver5.example.co.jp/"};
    /**
     * バックアップサーバ番号
     */
    private int serverNo = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
    }

    @Override
    protected void onResume() {
        super.onResume();
        // バックアップ処理起動状態更新
        updateBackupStatus();
    }

    /**
     * バックアップ処理起動状態更新
     */
    private void updateBackupStatus() {
        TextView textRun = (TextView) findViewById(R.id.textRun);
        Button startButton = (Button) findViewById(R.id.button_start);

        if (isRunning()) {
            // 稼働中の場合
            textRun.setText("稼働中");
            textRun.setTextColor(Color.RED);
        } else {
            // 停止中の場合
            textRun.setText("停止中");
            textRun.setTextColor(Color.BLACK);
        }
        startButton.setEnabled(!isRunning());
    }

    /**
     * 開始ボタンタップ
     */
    public void onClickStart(View v) {
        // アラームを開始する
        startAlarm(this);

		updateBackupStatus();
    }

    /**
     * アラーム開始
     */
    public void startAlarm(Context context) {
        // バックアップサーバ取得
        String backupServer = getNextBackupServer();

        Intent intent = new Intent();
        intent.setClassName("jp.go.ipa.sample.component.service", "jp.go.ipa.sample.component.service.BackupService");
        intent.putExtra("server", backupServer);

        // バックアップServiceの開始
        startService(intent);
    }

    /**
     * バックアップサーバ取得
     */
    private String getNextBackupServer() {
        // リストからサーバ名取得
        String server = BACKUP_SERVER[serverNo];

        // サーバ番号を進めておく
        serverNo++;

        // 番号がリストよりも大きくなる場合、０に戻す
        if (serverNo >= BACKUP_SERVER.length) {
            serverNo = 0;
        }

        return server;
    }


    /**
     * 稼働状態
     */
    private boolean isRunning() {
            if (isServiceRunning(this,"jp.go.ipa.sample.component.service.BackupService")) {
                // 稼働中
                return true;
            } else {
                // 停止中
                return false;
            }
    }

    public boolean isServiceRunning(Context c, String name) {
        ActivityManager am = (ActivityManager) c.getSystemService(Context.ACTIVITY_SERVICE);
        List<ActivityManager.RunningServiceInfo> runningService = am.getRunningServices(Integer.MAX_VALUE);
        for (ActivityManager.RunningServiceInfo i : runningService) {
            if (name.equals(i.service.getClassName())) {
                return true;
            }
        }
        return false;
    }

}
