package jp.go.ipa.sample.component.contentprovider;

import android.content.ContentValues;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.res.AssetManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Bundle;
import android.app.Activity;
import android.preference.PreferenceManager;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ImageView;
import android.widget.Toast;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class MainActivity extends Activity {

//カメラで撮影したら、画像追加する（機能は実装しない。UIにカメラボタンを配置するのみ）

    Cursor cursor;
    private Bitmap[] mBitmaps;

    private static final int BOOTED = 1;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //初回起動時のみ初期データを追加
        if (getInitState() != BOOTED) {
            initData();
            setState(BOOTED);
        }

        cursor = getContentResolver().query(Uri.parse("content://jp.go.ipa.sample.component.contentprovider"), null, null, null, null);
        mBitmaps = loadBitmap();

        GridAdapter gridAdapter = new GridAdapter(this);
        GridView gridView = (GridView) findViewById(R.id.gridView);
        gridView.setAdapter(gridAdapter);

        // 画像なしメッセージの表示
        if(cursor.getCount() == 0){
    		Toast.makeText(this, "表示できる画像がありません", Toast.LENGTH_LONG).show();
        }
    }

    @Override
    protected void onPause(){
    	super.onPause();
    	finish();
    }
    
    @Override
    protected void onStop() {
        super.onStop();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    /**
     * ContentProviderから画像を取得
     *
     * @return
     */
    private Bitmap[] loadBitmap() {
        Bitmap[] bitmaps = new Bitmap[cursor.getCount()];
        cursor.moveToFirst();
        for (int i = 0; i < cursor.getCount(); i++) {
            bitmaps[i] = BitmapFactory.decodeByteArray(cursor.getBlob(cursor.getColumnIndex("data")), 0, cursor.getBlob(cursor.getColumnIndex("data")).length);
            cursor.moveToNext();
        }
        return bitmaps;
    }

    /**
     * InputStreamをbyte[]変換
     *
     * @param input
     * @return
     * @throws IOException
     */
    private byte[] streamToByte(InputStream input) throws IOException {
        byte[] buffer = new byte[4096];
        int bytesRead;
        ByteArrayOutputStream output = new ByteArrayOutputStream();
        while ((bytesRead = input.read(buffer)) != -1) {
            output.write(buffer, 0, bytesRead);
        }
        return output.toByteArray();
    }

    /**
     * アプリで使用するデータの初期化
     *
     * @return
     */
    private boolean initData() {
        AssetManager assetManager = getResources().getAssets();
        String[] fileList = null;
        try {
            fileList = assetManager.list("img");

            ContentValues contentValues = new ContentValues();
            for (String aFileList : fileList) {
                contentValues.put("name", aFileList);
                //assetsから取得した画像ファイルをbyte変換してDBに格納する
                contentValues.put("data", streamToByte(assetManager.open("img/" + aFileList)));
                getContentResolver().insert(Uri.parse("content://jp.go.ipa.sample.component.contentprovider/write/"), contentValues);
                contentValues.clear();
            }
            return true;
        } catch (IOException e) {
            return false;
        }
    }



    /**
     * 画像グリッド表示のアダプタクラス
     */
    private class GridAdapter extends BaseAdapter {

        Context mContext;

        private GridAdapter(Context context) {
            mContext = context;
        }

        @Override
        public int getCount() {
            return mBitmaps.length;
        }

        @Override
        public Object getItem(int position) {
            return position;
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            // 画像表示用のImageView
            ImageView imageView;

            // convertViewがnullならImageViewを新規に作成する
            if (convertView == null) {
                imageView = new ImageView(mContext);
                imageView.setBackgroundResource(android.R.drawable.gallery_thumb);
                // convertViewがnullでない場合は再利用
            } else {
                imageView = (ImageView) convertView;
            }

            // ImageViewに画像ファイルを設定
            Drawable image = null;
            image = new BitmapDrawable(mBitmaps[position]);
            imageView.setImageDrawable(image);

            // ImageViewを返す
            return imageView;
        }
    }

    /**
     * SharedPreferenceに保存された初回起動かどうかの状態を取得する
     *
     * @return
     */
    private int getInitState() {
        // 読み込み
        int state;
        SharedPreferences sp = PreferenceManager
                .getDefaultSharedPreferences(getApplication().getApplicationContext());
        state = sp.getInt("InitState", 0);
        return state;
    }

    /**
     * 初回起動後に起動済みフラグをセット
     * @param state
     */
    private void setState(int state) {
        // SharedPreferences設定を保存
        SharedPreferences sp = PreferenceManager
                .getDefaultSharedPreferences(this);
        sp.edit().putInt("InitState", state).commit();
    }

    /**
     * 使用不可メッセージ表示
     * @param v
     */
	public void onClickNoFunction(View v) {
		
		Toast.makeText(this, "現在使用できません", Toast.LENGTH_LONG).show();
		
	}
}
