package jp.go.ipa.sample.fileaccess.data;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;

import jp.go.ipa.sample.fileaccess.data.R;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

/**
 * メイン画面Activityクラス
 */
public class MainActivity extends Activity {

	/** ファイル名 */
	private final String STRAGE_FILE_NAME = "APPDATA";

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		// リストの設定
		setListView();
	}

	@Override
	protected void onResume() {
		super.onResume();
		// 画面再表示時にリスト表示を更新する
		setListView();
	}

	/*
	 * リストの設定
	 */
	private void setListView() {
		// パスワード情報のリスト取得
		ArrayList<PasswordData> listPasswordData = getPasswordList();

		// 取得したパスワードのリストをListViewに設定する
		ListView listPassword = (ListView) findViewById(R.id.listPassword);
		ArrayAdapter<PasswordData> adapter = new ArrayAdapter<PasswordData>(this, android.R.layout.simple_list_item_1);
		for (int i = 0; i < listPasswordData.size(); i++) {
			adapter.add(listPasswordData.get(i));
		}
		listPassword.setAdapter(adapter);
		listPassword.setOnItemClickListener(new AdapterView.OnItemClickListener() {
			// リスト押下処理
			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
				ListView listView = (ListView) parent;
				// クリックされたパスワード情報を取得し、ダイアログにて表示する
				PasswordData item = (PasswordData) listView.getItemAtPosition(position);
				showDetailDialog(item);
			}
		});

	}

	/*
	 * 内部ストレージからリスト取得
	 */
	private ArrayList<PasswordData> getPasswordList() {
		InputStream inputStream = null;
		BufferedReader bufferedReader = null;

		ArrayList<PasswordData> listPasswordData = new ArrayList<PasswordData>();
		try {
			// 内部ストレージのファイルから情報を取得する
			inputStream = openFileInput(STRAGE_FILE_NAME);
			bufferedReader = new BufferedReader(new InputStreamReader(inputStream, "UTF-8"));
			while (true) {
				// 名称の取得
				String name = bufferedReader.readLine();
				if (name == null) {
					break;
				}

				// IDの取得
				String id = bufferedReader.readLine();
				if (id == null) {
					break;
				}

				// パスワードの取得
				String pass = bufferedReader.readLine();
				if (pass == null) {
					break;
				}

				// URLの取得
				String url = bufferedReader.readLine();
				if (url == null) {
					break;
				}

				// 備考の取得
				String etc = bufferedReader.readLine();
				if (etc == null) {
					break;
				}

				// 取得したパスワード情報をリストに追加
				listPasswordData.add(new PasswordData(name, id, pass, url, etc));
			}

		} catch (IOException e) {
			// 読み込み失敗
			e.printStackTrace();
		} finally {
			if (bufferedReader != null) {
				try {
					bufferedReader.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		return listPasswordData;
	}

	/*
	 * パスワード情報ダイアログ表示
	 */
	private void showDetailDialog(PasswordData passwordData) {
		// ダイアログに表示するメッセージを設定する
		String msg = "ID:" + passwordData.id + "\r\nPASS:" + passwordData.pass + "\r\nURL:" + passwordData.url + "\r\n備考:" + passwordData.etc;

		// ダイアログを表示する
		AlertDialog.Builder alertDialog = new AlertDialog.Builder(this);
		alertDialog.setTitle(passwordData.name);
		alertDialog.setMessage(msg);
		alertDialog.setPositiveButton("OK", null);
		alertDialog.show();
	}

	/*
	 * 登録ボタンタップ
	 */
	public void onClickRegister(View v) {
		// 登録画面に遷移する
		Intent intent = new Intent(this, RegisterActivity.class);
		startActivity(intent);
	}

	/*
	 * 削除ボタンタップ
	 */
	public void onClickDelete(View v) {
		// 内部ストレージのファイルを削除し、画面を更新する
		deleteFile(STRAGE_FILE_NAME);
		setListView();
		Toast.makeText(this, "ファイルを削除しました", Toast.LENGTH_LONG).show();
	}

	/*
	 * パスワード情報クラス
	 */
	private class PasswordData {
		/** 名称 */
		public String name;
		/** ID */
		public String id;
		/** パスワード */
		public String pass;
		/** URL */
		public String url;
		/** 備考 */
		public String etc;

		/*
		 * コンストラクタ
		 */
		public PasswordData(String name, String id, String pass, String url, String etc) {
			this.name = name;
			this.id = id;
			this.pass = pass;
			this.url = url;
			this.etc = etc;
		}

		/*
		 * リスト表示内容取得
		 */
		public String toString() {
			return name;
		}
	}
}
