package jp.go.ipa.sample.fileaccess.sd;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.DialogInterface;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.ContactsContract;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import java.io.*;
import java.util.ArrayList;

/**
 * メイン画面Activityクラス
 */
public class MainActivity extends Activity {

    @Override
	protected void onPause() {
		super.onPause();
		finish();
	}

	/**
     * ファイルの保存先
     */
    private final String FILE_NAME = "contacts.csv";
    private final String SD_FILE_PATH = Environment.getExternalStorageDirectory().getPath() + "/" + FILE_NAME;
    /**
     * CSV書き込み内容
     */
    private StringBuffer csvData = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        //　起動時のチェックを行い、電話帳データが空だったら、テストデータを3件追加する
        if (!existContacts()) {
        	//　テストデータの追加を確認するアラートダイアログ表示
        	showAlertDialog();
        }

        // 電話帳データ読込
        readContacts();
    }

    /**
     * 電話帳データ読込
     */
    private void readContacts() {
        // 電話帳データの取得
        Cursor cursor = managedQuery(ContactsContract.CommonDataKinds.Phone.CONTENT_URI, null, null, null, null);

        int displayNameIndex = cursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME);
        int phoneNumberIndex = cursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER);

        TextView txtContacts = (TextView) findViewById(R.id.txtContacts);

        // CSVデータヘッダの追加
        csvData = new StringBuffer("Name,PhoneNumber\r\n");
        while (cursor.moveToNext()) {
            // 書き込み用データの追加
            csvData.append(cursor.getString(displayNameIndex) + "," + cursor.getString(phoneNumberIndex) + "\r\n");
            // 一覧TextViewに電話帳の名称を追加する
            txtContacts.setText(txtContacts.getText().toString() + cursor.getString(displayNameIndex) + "\r\n");
        }
    }

    /*
     * SDカード書込ボタン
     */
    public void onClickSave(View v) {
        // 入力内容の取得
        String data = csvData.toString();
        FileOutputStream fileOutputStream = null;

        // 既存のファイルを一度削除した後、新たにファイルを作成
        File file = new File(SD_FILE_PATH);
        file.delete();

        file.getParentFile().mkdir();

        try {

            // ▼▼▼脆弱性のあるソースコード▼▼▼
            // 書き込み処理を行う
            fileOutputStream = new FileOutputStream(file, true);
            fileOutputStream.write(data.getBytes());
            // ▲▲▲脆弱性のあるソースコード▲▲▲

            // 完了メッセージ表示
            Toast.makeText(this, String.format("%s\r\nにバックアップが完了しました。", file.getAbsolutePath()), Toast.LENGTH_LONG).show();

        } catch (FileNotFoundException e) {
            // 書き込み失敗
            Toast.makeText(this, "ファイル書き込みに失敗しました", Toast.LENGTH_LONG).show();
            e.printStackTrace();
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (fileOutputStream != null) {
                try {
                    fileOutputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /*
     * SDカード削除ボタン
     */
    public void onClickDelete(View v) {
        File file = new File(SD_FILE_PATH);
        file.delete();
        Toast.makeText(this, "ファイルを削除しました", Toast.LENGTH_LONG).show();
    }

    /**
     * 電話帳データの存在チェック
     *
     * @return
     */
    private boolean existContacts() {
        // 電話帳データの取得
        Cursor cursor = managedQuery(ContactsContract.CommonDataKinds.Phone.CONTENT_URI, null, null, null, null);

        if (cursor.getCount() > 0) {
            //電話帳にデータあり
            return true;
        } else {
            //電話帳にデータなし
            return false;
        }
    }

    /**
     * assetsから電話帳に初期データの読み込み
     */
    private void addContacts() {

        ArrayList<ContactsData> list = new ArrayList<ContactsData>();
        
        ContactsData contactsDataFirst = new ContactsData("情報 一郎", "01234567890");
        list.add(contactsDataFirst);
        
        ContactsData contactsDataSecond = new ContactsData("情報 二郎", "01234567890");
        list.add(contactsDataSecond);
        
        ContactsData contactsDataThird = new ContactsData("情報 三郎", "01234567890");
        list.add(contactsDataThird);
        
        for (int i=0; i<3; i++) {
        	
        ContentValues values = new ContentValues();
        Uri rawContactUri = getContentResolver().insert(ContactsContract.RawContacts.CONTENT_URI, values);	
        long rawContactId = ContentUris.parseId(rawContactUri);
        values.clear();
        values.put(ContactsContract.Data.RAW_CONTACT_ID, rawContactId);
        values.put(ContactsContract.Data.MIMETYPE, ContactsContract.CommonDataKinds.StructuredName.CONTENT_ITEM_TYPE);
        values.put(ContactsContract.CommonDataKinds.StructuredName.DISPLAY_NAME, list.get(i).name);
        getContentResolver().insert(ContactsContract.Data.CONTENT_URI, values);

        // 携帯の電話番号を登録
        Uri mobileUri = Uri.withAppendedPath(rawContactUri, ContactsContract.Contacts.Data.CONTENT_DIRECTORY);
        values.clear();
        values.put(ContactsContract.CommonDataKinds.Phone.TYPE, ContactsContract.CommonDataKinds.Phone.TYPE_MOBILE);
        values.put(ContactsContract.CommonDataKinds.Phone.IS_SUPER_PRIMARY, 1);
        values.put(ContactsContract.Data.MIMETYPE, ContactsContract.CommonDataKinds.Phone.CONTENT_ITEM_TYPE);
        values.put(ContactsContract.CommonDataKinds.Phone.NUMBER, list.get(i).number);
        getContentResolver().insert(mobileUri, values);
        
        }
       // 電話帳データ読込
        readContacts();

    }
    
    /*
	 * 電話帳情報クラス
	 */
	private class ContactsData {
		/** 名前 */
		public String name;
		/** 電話番号 */
		public String number;

		/*
		 * コンストラクタ
		 */
		public ContactsData(String name, String number) {
			this.name = name;
			this.number = number;
		}

		/*
		 * リスト表示内容取得
		 */
		public String toString() {
			return name;
		}
	}
    
    /**
     * アラートダイアログの表示
     */
    private void showAlertDialog() {
    	
    	 AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(this);
         // アラートダイアログのタイトルを設定
         alertDialogBuilder.setTitle("注意");
         // アラートダイアログのメッセージを設定
         alertDialogBuilder.setMessage("電話帳データが存在しないので、テストデータを登録します。よろしいですか？");
         // アラートダイアログのはいボタンがクリックされた時に電話帳にテストデータを登録
         alertDialogBuilder.setPositiveButton("はい",
                 new DialogInterface.OnClickListener() {
                     @Override
                     public void onClick(DialogInterface dialog, int which) {
                    	 
                    	 addContacts();
                    	 
                     }
                 });
         // アラートダイアログのいいえボタンがクリックされた時にアプリを終了
         alertDialogBuilder.setNegativeButton("いいえ",
                 new DialogInterface.OnClickListener() {
                     @Override
                     public void onClick(DialogInterface dialog, int which) {
                    	 finish();
                     }
                 });
         // アラートダイアログのキャンセルが可能かどうかを設定します
         alertDialogBuilder.setCancelable(false);
         AlertDialog alertDialog = alertDialogBuilder.create();
         // アラートダイアログを表示します
         alertDialog.show();
    }

}
