package jp.go.ipa.sample.component.broadcast;

import java.util.ArrayList;
import java.util.Map;
import java.util.Set;
import jp.go.ipa.sample.component.broadcast.R;
import android.app.Activity;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Gravity;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

public class MainActivity extends Activity {

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		// 画像リスト作成
		createPictureList();
		
	}

	@Override
	protected void onPause() {
		super.onPause();
		finish();
	}

	
	/**
	 * 画像リスト作成
	 */
	private void createPictureList() {
		// 画像データ読込
		ArrayList<PreferenceData> list = readPicture();

		// 取得したパスワードのリストをListViewに設定する
		ListView listFriend = (ListView) findViewById(R.id.listFriend);
		ArrayAdapter<PreferenceData> adapter = new ArrayAdapter<PreferenceData>(this, android.R.layout.simple_list_item_single_choice);
		for (int i = 0; i < list.size(); i++) {
			adapter.add(list.get(i));
		}
		listFriend.setAdapter(adapter);
		listFriend.setChoiceMode(ListView.CHOICE_MODE_SINGLE);
	}

	/**
	 * 画像データ読込
	 */
	private ArrayList<PreferenceData> readPicture() {
		ArrayList<PreferenceData> list = new ArrayList<PreferenceData>();


        SharedPreferences sharedPref = PreferenceManager.getDefaultSharedPreferences(this);

        int count = 0;

        Map<String,?> sharedPrefAll = sharedPref.getAll();
        Set<String> keys = sharedPrefAll.keySet();
        for(String name : keys){

            PreferenceData preferenceData = new PreferenceData(sharedPref.getString(name,""),Integer.toString(count));
            list.add(preferenceData);

            count++;
        }
		return list;
	}

	/*
	 * 送信ボタンタップ
	 */
	public void onClickSend(View v) {
		// 送信画像の取得
		ListView listFriend = (ListView) findViewById(R.id.listFriend);
		int pos = listFriend.getCheckedItemPosition();

		// 送信画像が指定されていない場合は以降の処理は行わない
		if (pos < 0) {
			Toast toast = Toast.makeText(this, "送信画像を選択してください", Toast.LENGTH_SHORT);
			toast.setGravity(Gravity.AXIS_CLIP, 0, 0);
			toast.show();
			return;
		}

		Toast toast = Toast.makeText(getApplicationContext(), "送信完了", Toast.LENGTH_LONG);
		toast.setGravity(Gravity.AXIS_CLIP, 0, 0);
		toast.show();
	}

	/*
	 * Preference情報クラス
	 */
	private class PreferenceData {
		/** 名前 */
		public String name;

		/*
		 * コンストラクタ
		 */
		public PreferenceData(String name, String number) {
			this.name = name;
		}

		/*
		 * リスト表示内容取得
		 */
		public String toString() {
			return name;
		}
	}
    
	// 送信画像の削除
    public void onClickDelete(View v) {
    	SharedPreferences sharedPreferences = PreferenceManager.getDefaultSharedPreferences(this);
    	SharedPreferences.Editor editor = sharedPreferences.edit();
    	Map<String, ?> keys = sharedPreferences.getAll();
    	if (keys.size() > 0) {
    	    for (String key : keys.keySet()) {
    	        editor.remove(key);
    	    }
    	    editor.commit();
    	    Toast.makeText(getApplicationContext(), "削除が完了しました。", Toast.LENGTH_LONG).show();
    	}
		createPictureList();
    }
    
}
